{% load i18n %}
<li class="{{ parent_item.is_active|yesno:' active,' }}{{ parent_item.children|yesno:' has-children,' }}">
    <a href="{{ parent_item.url }}"
            {{ parent_item.target_blank|yesno:' target=_blank,' }}>{% if suit_layout == 'vertical' %}<i class="{% firstof parent_item.icon 'fa fa-chevron-right' %}"></i>{% endif %}{% trans parent_item.label|capfirst %}
    </a>
    {% if parent_item.children %}
        {% if not parent_item.is_active or suit_layout == 'vertical' %}
            <ul class="sub-nav">
                {% for child_item in parent_item.children %}
                    <li{{ child_item.is_active|yesno:' class=active,' }}>
                        <a href="{{ child_item.url }}"
                                {{ child_item.target_blank|yesno:' target=_blank,' }}>{{ child_item.label }}</a>
                    </li>
                {% endfor %}
            </ul>
        {% endif %}
    {% endif %}
</li>
